@@ -30,6 +30,7 @@
 #include <cairo-svg.h>
 #include <string.h>
 
+#ifdef GOFFICE_WITH_LIBRSVG
 #include <librsvg/rsvg.h>
 #ifdef LIBRSVG_CHECK_VERSION
 #define NEEDS_LIBRSVG_CAIRO_H !LIBRSVG_CHECK_VERSION(2,36,2)
@@ -39,6 +40,7 @@
 #if NEEDS_LIBRSVG_CAIRO_H
 #include <librsvg/rsvg-cairo.h>
 #endif
+#endif /* GOFFICE_WITH_LIBRSVG */
 
 struct _GOComponentPrivate {
 	gboolean is_inline; /* if set, the object will be displayed in compact mode
@@ -285,6 +287,7 @@ go_component_snapshot_render (GOComponent *component, cairo_t *cr,
 {
 	GOComponentSnapshot *snapshot = (GOComponentSnapshot *) component;
 	switch (component->snapshot_type) {
+#ifdef GOFFICE_WITH_LIBRSVG
 	case GO_SNAPSHOT_SVG:
 		/* NOTE: we might use lasem here, and also use a GOSvg image */
 		if (snapshot->image == NULL) {
@@ -312,6 +315,7 @@ go_component_snapshot_render (GOComponent *component, cairo_t *cr,
 			cairo_restore (cr);
 		}
 		break;
+#endif /* GOFFICE_WITH_LIBRSVG */
 	case GO_SNAPSHOT_PNG: {
 		if (snapshot->image == NULL) {
 			GInputStream *in = g_memory_input_stream_new_from_data (
@@ -998,7 +1002,6 @@ go_component_set_inline (GOComponent *component, gboolean is_inline)
  * go_component_get_inline:
  * @component: a #GOComponent
  *
- * Returns the in-line or not nature of the component.
  * Returns: whether the component is displayed in-line
  **/
 gboolean
@@ -1027,8 +1030,6 @@ go_component_set_use_font_from_app (GOComponent *component, gboolean use_font_fr
  * go_component_get_use_font_from_app:
  * @component: a #GOComponent
  *
- * Returns whether the component should use the font from the calling
- * application or use its own font.
  * Returns: whether the component should use the font from the calling
  * application
  **/
