@@ -634,12 +634,6 @@ static GSF_CLASS (GOMenuColor, go_menu_color,
 		  go_menu_color_class_init, NULL,
 		  GTK_TYPE_MENU)
 
-static void
-cb_menu_item_toggle_size_request (GtkWidget *item, gint *requitision)
-{
-	*requitision = 1;
-}
-
 static GtkWidget *
 make_colored_menu_item (char const *label, GOColor c)
 {
@@ -663,9 +657,6 @@ make_colored_menu_item (char const *label, GOColor c)
 
 	g_object_set_data (G_OBJECT (button), "go_color", GINT_TO_POINTER (c));
 
-	/* Workaround for bug http://bugzilla.gnome.org/show_bug.cgi?id=585421 */
-	g_signal_connect (button, "toggle-size-request", G_CALLBACK (cb_menu_item_toggle_size_request), NULL);
-
 	return button;
 }
 
