@@ -260,9 +260,9 @@ go_search_replace_compile (GOSearchReplace *sr)
  * go_search_replace_verify:
  * @sr: Search-and-Replace info to be checked
  * @repl: Check replacement part too.
- * @err: Location to store error message.
+ * @err: (out) (optional) (nullable): #GError
  *
- * Returns: %TRUE if  search-and-replace data is valid.
+ * Returns: %TRUE if search-and-replace data is valid.
  **/
 gboolean
 go_search_replace_verify (GOSearchReplace *sr, gboolean repl, GError **err)
@@ -494,8 +494,7 @@ calculate_replacement (GOSearchReplace *sr, const char *src, const GORegmatch *p
 			}
 		}
 
-		res = gres->str;
-		g_string_free (gres, FALSE);
+		res = g_string_free (gres, FALSE);
 	}
 
 	/*
